@@ -8,20 +8,20 @@ Small module that makes your journey with RMV REST API somehow easier. Based ful
 ```py
 import pyrmv
 
-# Set API key
-access_id = "Something"
+# Define a Client with API key
+client = pyrmv.Client("AcessId")
 
 # Get origin's and destination's location
-origin = pyrmv.stop_by_name(access_id, "Frankfurt Hauptbahnhof", max_number=3)[0]
-destination = pyrmv.stop_by_coords(access_id, 50.099613, 8.685449, max_number=3)[0]
+origin = client.stop_by_name("Frankfurt Hauptbahnhof", max_number=3)[0]
+destination = client.stop_by_coords(50.099613, 8.685449, max_number=3)[0]
 
 # Find a trip by locations got
-trip = pyrmv.trip_find(access_id, origin_id=origin.id, dest_id=destination.id)
+trip = client.trip_find(origin_id=origin.id, dest_id=destination.id)
 ```
 """
 
 __name__ = "pyrmv"
-__version__ = "0.2.5"
+__version__ = "0.3.0"
 __license__ = "MIT License"
 __author__ = "Profitroll"
 
@@ -30,5 +30,6 @@ from . import const
 from . import enums
 from . import errors
 from . import utility
-from . import classes
-from .methods import *
\ No newline at end of file
+from .classes import *
+from .classes.Client import Client
+# from .methods import *
\ No newline at end of file
