@@ -1,5 +1,5 @@
-from datetime import datetime
 from requests import get
+from datetime import datetime, timedelta
 from typing import Union
 from xmltodict import parse as xmlparse
 
@@ -79,9 +79,15 @@ def board_departure(accessId: str,
                     payload[str(var)] = val.strftime("%H:%M")
                 else:
                     payload[str(var)] = val
+        elif str(var) == "duration":
+            if val != None:
+                if isinstance(val, timedelta):
+                    payload[str(var)] = val.minutes
+                else:
+                    payload[str(var)] = val
         elif str(var) == "boardType":
             if val != None:
-                payload["type"] = val
+                payload["type"] = val.upper()
         elif str(var) not in ["json", "headers", "payload"]:
             if val != None:
                 payload[str(var)] = val
