@@ -117,6 +117,15 @@ def him_search(accessId: str,
                     payload[str(var)] = weekdays_bitmask(val)
                 else:
                     payload[str(var)] = val
+        elif str(var) == "searchmode":
+            if val != None:
+                payload["searchmode"] = val.upper()
+        elif str(var) == "affectedJourneyMode":
+            if val != None:
+                payload["affectedJourneyMode"] = val.upper()
+        elif str(var) == "affectedJourneyStopMode":
+            if val != None:
+                payload["affectedJourneyStopMode"] = val.upper()
         elif str(var) not in ["json", "headers", "payload"]:
             if val != None:
                 payload[str(var)] = val
