@@ -54,7 +54,13 @@ def stop_by_coords(accessId: str,
     payload = {}
 
     for var, val in locals().items():
-        if str(var) not in ["json", "headers", "payload", "raw_response"]:
+        if str(var) == "stopType":
+            if val != None:
+                payload["type"] = val.upper()
+        elif str(var) == "locationSelectionMode":
+            if val != None:
+                payload["locationSelectionMode"] = val.upper()
+        elif str(var) not in ["json", "headers", "payload", "raw_response"]:
             if val != None:
                 payload[str(var)] = val
 
