@@ -68,7 +68,13 @@ def stop_by_name(accessId: str,
         if str(var) == "inputString":
             if val != None:
                 payload["input"] = val
-        elif str(var) not in ["json", "headers", "payload", "raw_response"]:
+        elif str(var) == "stopType":
+            if val != None:
+                payload["type"] = val.upper()
+        elif str(var) == "filterMode":
+            if val != None:
+                payload["filterMode"] = val.upper()
+        elif str(var) not in ["json", "headers", "payload", "raw_response", "stopType"]:
             if val != None:
                 payload[str(var)] = val
 
