@@ -239,6 +239,9 @@ def trip_find(accessId: str,
                     payload[str(var)] = val.strftime("%H:%M")
                 else:
                     payload[str(var)] = val
+        elif str(var) == "rtMode":
+            if val != None:
+                payload["rtMode"] = val.upper()
         elif str(var) not in ["json", "headers", "payload"]:
             if val != None:
                 payload[str(var)] = val
